/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { AdminTenantsApi, AdminUsersApi, AlfrescoApi, ContentClient, GroupsApi, NodesApi, PeopleApi, QueriesApi, SearchApi, SecurityGroupsApi, SecurityMarksApi, SitesApi, UploadApi, SharedlinksApi, FavoritesApi, TrashcanApi, PersonEntry, CommentsApi, CategoriesApi, TagsApi } from '@alfresco/js-api';
import { PersonModel } from './people-api-models';
export interface AcaBackend {
    sites: SitesApi;
    upload: UploadApi;
    nodes: NodesApi;
    share: SharedlinksApi;
    favorites: FavoritesApi;
    trashCan: TrashcanApi;
    tearDown(): Promise<any>;
}
export declare class ApiClientFactory {
    alfrescoApi: AlfrescoApi;
    sites: SitesApi;
    upload: UploadApi;
    nodes: NodesApi;
    people: PeopleApi;
    adminUsers: AdminUsersApi;
    adminTenant: AdminTenantsApi;
    groups: GroupsApi;
    queries: QueriesApi;
    search: SearchApi;
    securityGroupsApi: SecurityGroupsApi;
    securityMarksApi: SecurityMarksApi;
    contentClient: ContentClient;
    share: SharedlinksApi;
    favorites: FavoritesApi;
    trashCan: TrashcanApi;
    commentsApi: CommentsApi;
    queriesApi: QueriesApi;
    categoriesApi: CategoriesApi;
    tagsApi: TagsApi;
    constructor();
    setUpAcaBackend(userName: string, password?: string): Promise<AcaBackend>;
    tearDown(): Promise<ApiClientFactory>;
    login(userName: string, password?: string): Promise<void>;
    loginUser(user: PersonModel): Promise<void>;
    createUser(user: PersonModel): Promise<PersonEntry>;
    changePassword(username: string, newPassword: string): Promise<PersonEntry>;
}
