/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { LoginPage, MyLibrariesPage, PersonalFilesPage, FavoritesLibrariesPage, SearchPage, SharedPage, TrashPage } from '../page-objects';
import { NodesApi, SitesApi, TrashcanApi } from '../api';
export declare class Utils {
    static readonly string257Long: string;
    static readonly string513Long: string;
    static random(): string;
    static retryCall(fn: () => Promise<any>, retry?: number, delay?: number): Promise<any>;
    static formatDate(date: string): string;
    /**
     * Method used to login user with navigation. Also waits for the page to load after login
     *
     * @param loginPage page context passed from the test
     * @param username username string
     * @param password password string
     * @param errorMessage error message string if the login fails
     *
     */
    static tryLoginUser(loginPage: LoginPage, username: string, password: string, errorMessage?: string): Promise<void>;
    /**
     * Method used to delete nodes and sites from user's account
     *
     * @param nodesApi nodesApi initialized with user credentials passed from the test
     * @param trashcanApi trashcanApi initialized with user credentials passed from the test
     * @param errorMessage error message string if the deleting sites/nodes fails
     * @param sitesApi sitesApi initialized with user credentials passed from the test
     * @param sitesToDelete array of sites' ids
     *
     */
    static deleteNodesSitesEmptyTrashcan(nodesApi?: NodesApi, trashcanApi?: TrashcanApi, errorMessage?: string, sitesApi?: SitesApi, sitesToDelete?: string[]): Promise<void>;
    static uploadFileNewVersion(personalFilesPage: PersonalFilesPage, fileFromOS: string): Promise<void>;
    static reloadPageIfRowNotVisible(pageContext: PersonalFilesPage | MyLibrariesPage | FavoritesLibrariesPage | SearchPage | SharedPage, nodeName: string, errorMessage?: string): Promise<void>;
    static reloadPageIfDatatableEmpty(pageContext: PersonalFilesPage | MyLibrariesPage | FavoritesLibrariesPage | SearchPage | SharedPage | TrashPage, errorMessage?: string): Promise<void>;
    static getCurrentAndPreviousDay(currentDate?: Date): {
        currentDate: string;
        previousDate: string;
    };
    static verifyZipFileContent(filePath: string, fileOrFolderName: string[]): Promise<boolean>;
    private static isFileOrFolderInEntries;
    /**
     * Method used trim all elements of an array from all spaces characters
     *
     * @param arr array needed to be trimmed
     *
     */
    static trimArrayElements(arr: string[]): string[];
    /**
     * Waits for a specific API response.
     *
     * @param page - The Playwright page object.
     * @param urlSubstring - The substring to look for in the URL.
     * @param statusCode - The expected status code of the response.
     */
    static waitForApiResponse(contentPage: LoginPage | MyLibrariesPage | PersonalFilesPage | FavoritesLibrariesPage | SearchPage | SharedPage | TrashPage, urlSubstring: string, statusCode: number): Promise<void>;
}
